@@ -1,6 +1,6 @@
 #' @title Test code in a temporary directory.
 #' @export
-#' @family tar_test
+#' @family utilities to extend targets
 #' @description Runs a `test_that()` unit test inside a temporary
 #'   directory to avoid writing to the user's file space.
 #'   This helps ensure compliance with CRAN policies.
@@ -23,7 +23,7 @@
 tar_test <- function(label, code) {
   platform <- tolower(Sys.info()[["sysname"]])
   if (platform != "solaris") {
-    assert_package("testthat")
+    tar_assert_package("testthat")
     code <- substitute(code)
     expr <- substitute(
       tar_dir(testthat::test_that(label, code)),
