@@ -3,12 +3,10 @@
 #' @family debug
 #' @description Load the packages, workspace, and random number generator seed
 #'   of target attempted with a workspace file.
-#' @details If you set `error = "workspace"` in [tar_option_set()]
-#'   or [tar_target()], then if that target throws an error
-#'   in [tar_make()], it will save its workspace to an RDS file
-#'   in `_targets/workspaces/`. Workspaces also get saved for targets
-#'   supplied to the `workspace` argument of [tar_option_set()],
-#'   even individual branches. The workspace is a compact reference
+#' @details If you activate workspaces through the `workspaces` argument
+#'   of [tar_option_set()], then under the circumstances you specify,
+#'   `targets` will save a special workspace file to a location in
+#'   in `_targets/workspaces/`. The workspace file is a compact reference
 #'   that allows `tar_workspace()` to load the target's dependencies
 #'   and random number generator seed as long as the data objects
 #'   are still in the data store (usually files in `_targets/objects/`).
@@ -20,7 +18,8 @@
 #'   workspace where the error happened. These objects include
 #'   the global objects at the time [tar_make()] was called and the
 #'   dependency targets. The random number generator seed for the
-#'   target is also assigned with `set.seed()`
+#'   target is also assigned with `set.seed()`.
+#' @inheritParams tar_validate
 #' @param name Symbol, name of the target whose workspace to read.
 #' @param envir Environment in which to put the objects.
 #' @param packages Logical, whether to load the required packages
@@ -30,11 +29,11 @@
 #'   should either be the global environment or inherit from the
 #'   global environment.
 #' @examples
-#' if (identical(Sys.getenv("TAR_LONG_EXAMPLES"), "true")) {
+#' if (identical(Sys.getenv("TAR_EXAMPLES"), "true")) {
 #' tar_dir({ # tar_dir() runs code from a temporary directory.
 #' tmp <- sample(1)
 #' tar_script({
-#'   tar_option_set(error = "workspace")
+#'   tar_option_set(workspace_on_error = TRUE)
 #'   list(
 #'     tar_target(x, "loaded"),
 #'     tar_target(y, stop(x))
@@ -55,13 +54,15 @@ tar_workspace <- function(
   name,
   envir = parent.frame(),
   packages = TRUE,
-  source = TRUE
+  source = TRUE,
+  script = targets::tar_config_get("script"),
+  store = targets::tar_config_get("store")
 ) {
   force(envir)
-  name <- deparse_language(substitute(name))
-  assert_chr(name)
-  assert_scalar(name)
-  workspace <- workspace_read(name)
+  name <- tar_deparse_language(substitute(name))
+  tar_assert_chr(name)
+  tar_assert_scalar(name)
+  workspace <- workspace_read(name = name, path_store = store)
   workspace_populate(workspace)
   workspace_assign(workspace, envir)
   if (packages) {
@@ -69,7 +70,7 @@ tar_workspace <- function(
     build_load_packages(command$packages, command$library)
   }
   if (source) {
-    source(path_script(), local = envir)
+    eval(parse(text = readLines(script)), envir = envir)
   }
   set.seed(workspace$target$command$seed)
   invisible()
