@@ -1,22 +1,44 @@
 # Should show a glimpse.
 net <- glimpse_init(pipeline_cross())
-vis <- visnetwork_init(network = net)
+vis <- visnetwork_init(network = net, degree_from = 1, degree_to = 1)
 vis$update()
+# Click on the nodes and see highlighted neighborhoods of degree 1.
 vis$visnetwork
 
 # Should show an inspection with everything outdated.
 net <- inspection_init(pipeline_cross())
-vis <- visnetwork_init(network = net)
+vis <- visnetwork_init(network = net, degree_from = 2, degree_to = 0)
+vis$update()
+# Click on the nodes and see highlighted neighborhoods
+# of upstream degree 2 and downstream degree 0.
+vis$visnetwork
+
+# Same but with everything queued.
+net <- inspection_init(pipeline_cross(), outdated = FALSE)
+vis <- visnetwork_init(network = net, degree_from = 2, degree_to = 0)
 vis$update()
 vis$visnetwork
 
 # Should show an inspection with everything up to date
-local_init(pipeline = pipeline_cross(), reporter = "silent")$run()
+local_init(pipeline = pipeline_cross(), reporter = "summary")$run()
 net <- inspection_init(pipeline_cross())
 vis <- visnetwork_init(network = net)
 vis$update()
 vis$visnetwork
 
+# Same with everything built.
+net <- inspection_init(pipeline_cross(), outdated = FALSE)
+vis <- visnetwork_init(network = net)
+vis$update()
+vis$visnetwork
+
+# Same with everything skipped.
+local_init(pipeline = pipeline_cross(), reporter = "summary")$run()
+net <- inspection_init(pipeline_cross(), outdated = FALSE)
+vis <- visnetwork_init(network = net)
+vis$update()
+vis$visnetwork
+
 # Should show all optional labels.
 tar_script({
   list(
@@ -205,25 +227,68 @@ tar_glimpse()
 # Should show a glimpse of just y1 and y2.
 tar_glimpse(allow = starts_with("y"))
 
+# Should show a glimpse of just z.
+tar_glimpse(exclude = starts_with("y"))
+
+# Should show a glimpse of y1, y2, and z.
+tar_glimpse(names = starts_with("z"))
+
+# Should show a glimpse of just z.
+tar_glimpse(names = starts_with("z"), shortcut = TRUE)
+
 # Should show a graph of 3 targets and f() and g().
 tar_visnetwork(targets_only = FALSE)
 
 # Should show a graph of 3 targets, f(), g(), and miscellaneous globals.
 tar_visnetwork(targets_only = FALSE, callr_function = NULL)
 
-# Should show a status of targets as dormant (light gray).
+# Should show a status of targets as queued (light gray).
 tar_visnetwork(targets_only = FALSE, outdated = FALSE)
 
 # Should show a graph of just y1 and y2.
 tar_visnetwork(allow = starts_with("y"))
 
-# Should show status dormant (light gray).
+# Should show a graph of z, f, and g.
+tar_visnetwork(exclude = starts_with("y"))
+
+# Should show a graph of everything.
+tar_visnetwork(names = starts_with("z"))
+
+# Should show a graph of just z.
+tar_make()
+tar_visnetwork(names = starts_with("z"), shortcut = TRUE)
+
+# Should show status queued (light gray).
+tar_destroy()
 tar_visnetwork(outdated = FALSE)
 
 # Should show a canceled target.
 tar_script(list(tar_target(y1, tar_cancel())))
 tar_make()
 tar_visnetwork(outdated = FALSE)
-           
+
+# Neighborhoods
+tar_script({
+  g <- function(x) x - 1
+  f <- function(x) g(x) + 1
+  list(
+    tar_target(y1, f(1)),
+    tar_target(y2, 1 + 1),
+    tar_target(z, y1 + y2),
+    tar_target(a, z),
+    tar_target(b, a),
+    tar_target(c, a),
+    tar_target(d, c),
+    tar_target(e, d)
+  )
+})
+
+# Click for highlighted neighborhoods
+# of upstream degree 1 and downstream degree 2.
+tar_glimpse(degree_to = 2)
+
+# Same with tar_visnetwork()
+tar_visnetwork(degree_to = 2)
+
 unlink("_targets.R")
 unlink("_targets", recursive = TRUE)
