@@ -29,14 +29,16 @@ tar_test("error with no message", {
 })
 
 tar_test("run with warning", {
+  skip_on_cran()
   build <- expect_warning(
-    build_init(quote(warning(12345)), baseenv()),
+    build_init(quote(warning("12345")), baseenv()),
     regexp = "12345"
   )
   expect_true(any(grepl("12345", build$metrics$warnings)))
 })
 
 tar_test("warning with no message", {
+  skip_on_cran()
   build <- expect_warning(build_init(quote(warning()), baseenv()))
   expect_equal(build$metrics$warnings, ".")
 })
